@@ -1,6 +1,6 @@
 /*
-** Copyright (c) 2018-2020 Valve Corporation
-** Copyright (c) 2018-2020 LunarG, Inc.
+** Copyright (c) 2018-2020,2022 Valve Corporation
+** Copyright (c) 2018-2020,2022 LunarG, Inc.
 **
 ** Permission is hereby granted, free of charge, to any person obtaining a
 ** copy of this software and associated documentation files (the "Software"),
@@ -37,7 +37,7 @@ GFXRECON_BEGIN_NAMESPACE(decode)
 
 FileProcessor::FileProcessor() :
     file_header_{}, file_descriptor_(nullptr), current_frame_number_(0), bytes_read_(0),
-    error_state_(kErrorInvalidFileDescriptor), annotation_handler_(nullptr), compressor_(nullptr), api_call_index_(0)
+    error_state_(kErrorInvalidFileDescriptor), annotation_handler_(nullptr), compressor_(nullptr), block_index_(0)
 {}
 
 FileProcessor::~FileProcessor()
@@ -214,6 +214,7 @@ bool FileProcessor::ProcessBlocks()
                     {
                         // Make sure to increment the frame number on the way out.
                         ++current_frame_number_;
+                        ++block_index_;
                         break;
                     }
                 }
@@ -298,6 +299,7 @@ bool FileProcessor::ProcessBlocks()
                 error_state_ = kErrorReadingBlockHeader;
             }
         }
+        ++block_index_;
     }
 
     return success;
@@ -396,7 +398,7 @@ bool FileProcessor::ProcessFunctionCall(const format::BlockHeader& block_header,
     size_t      parameter_buffer_size = static_cast<size_t>(block_header.size) - sizeof(call_id);
     uint64_t    uncompressed_size     = 0;
     ApiCallInfo call_info             = {};
-    call_info.index                   = api_call_index_;
+    call_info.index                   = block_index_;
     bool success                      = ReadBytes(&call_info.thread_id, sizeof(call_info.thread_id));
 
     if (success)
@@ -454,8 +456,6 @@ bool FileProcessor::ProcessFunctionCall(const format::BlockHeader& block_header,
                     DecodeAllocator::End();
                 }
             }
-
-            ++api_call_index_;
         }
     }
     else
@@ -628,6 +628,81 @@ bool FileProcessor::ProcessMetaData(const format::BlockHeader& block_header, for
             HandleBlockReadError(kErrorReadingBlockHeader, "Failed to read display message meta-data block header");
         }
     }
+    else if (meta_data_type == format::MetaDataType::kCreateHardwareBufferCommand_deprecated)
+    {
+        format::CreateHardwareBufferCommandHeader_deprecated header;
+
+        GFXRECON_LOG_WARNING_ONCE(
+            "This capture contains a deprecated metacommand to create an AHardwareBuffer.  While still supported, this "
+            "metacommand may not correctly represent some state of the captured AHardwareBuffer.");
+
+        success = ReadBytes(&header.thread_id, sizeof(header.thread_id));
+        success = success && ReadBytes(&header.memory_id, sizeof(header.memory_id));
+        success = success && ReadBytes(&header.buffer_id, sizeof(header.buffer_id));
+        success = success && ReadBytes(&header.format, sizeof(header.format));
+        success = success && ReadBytes(&header.width, sizeof(header.width));
+        success = success && ReadBytes(&header.height, sizeof(header.height));
+        success = success && ReadBytes(&header.stride, sizeof(header.stride));
+        success = success && ReadBytes(&header.usage, sizeof(header.usage));
+        success = success && ReadBytes(&header.layers, sizeof(header.layers));
+        success = success && ReadBytes(&header.planes, sizeof(header.planes));
+
+        if (success)
+        {
+            std::vector<format::HardwareBufferPlaneInfo> entries;
+
+            for (uint64_t i = 0; i < header.planes; ++i)
+            {
+                format::HardwareBufferPlaneInfo entry;
+
+                if (!ReadBytes(&entry, sizeof(entry)))
+                {
+                    success = false;
+                    break;
+                }
+
+                entries.emplace_back(std::move(entry));
+            }
+
+            if (success)
+            {
+                for (auto decoder : decoders_)
+                {
+                    if (decoder->SupportsMetaDataId(meta_data_id))
+                    {
+                        decoder->DispatchCreateHardwareBufferCommand(header.thread_id,
+                                                                     header.memory_id,
+                                                                     header.buffer_id,
+                                                                     header.format,
+                                                                     header.width,
+                                                                     header.height,
+                                                                     header.stride,
+                                                                     header.usage,
+                                                                     header.layers,
+                                                                     entries);
+                    }
+                }
+            }
+            else
+            {
+                if (format::IsBlockCompressed(block_header.type))
+                {
+                    HandleBlockReadError(kErrorReadingCompressedBlockData,
+                                         "Failed to read create hardware buffer meta-data block");
+                }
+                else
+                {
+                    HandleBlockReadError(kErrorReadingBlockData,
+                                         "Failed to read create hardware buffer meta-data block");
+                }
+            }
+        }
+        else
+        {
+            HandleBlockReadError(kErrorReadingBlockHeader,
+                                 "Failed to read create hardware buffer meta-data block header");
+        }
+    }
     else if (meta_data_type == format::MetaDataType::kCreateHardwareBufferCommand)
     {
         format::CreateHardwareBufferCommandHeader header;
@@ -1200,8 +1275,8 @@ bool FileProcessor::ProcessStateMarker(const format::BlockHeader& block_header,
 bool FileProcessor::ProcessAnnotation(const format::BlockHeader& block_header, format::AnnotationType annotation_type)
 {
     bool     success      = false;
-    uint32_t label_length = 0;
-    uint32_t data_length  = 0;
+    decltype(format::AnnotationHeader::label_length) label_length = 0;
+    decltype(format::AnnotationHeader::data_length)  data_length  = 0;
 
     success = ReadBytes(&label_length, sizeof(label_length));
     success = success && ReadBytes(&data_length, sizeof(data_length));
@@ -1211,7 +1286,9 @@ bool FileProcessor::ProcessAnnotation(const format::BlockHeader& block_header, f
         {
             std::string label;
             std::string data;
-            auto        total_length = label_length + data_length;
+            const auto  size_sum = label_length + data_length;
+            GFXRECON_CHECK_CONVERSION_DATA_LOSS(size_t, size_sum);
+            const size_t total_length = static_cast<size_t>(size_sum);
 
             success = ReadParameterBuffer(total_length);
             if (success)
@@ -1225,11 +1302,12 @@ bool FileProcessor::ProcessAnnotation(const format::BlockHeader& block_header, f
                 if (data_length > 0)
                 {
                     auto data_start = std::next(parameter_buffer_.begin(), label_length);
-                    data.assign(data_start, std::next(data_start, data_length));
+                    GFXRECON_CHECK_CONVERSION_DATA_LOSS(size_t, data_length);
+                    data.assign(data_start, std::next(data_start, static_cast<size_t>(data_length)));
                 }
 
                 assert(annotation_handler_ != nullptr);
-                annotation_handler_->ProcessAnnotation(annotation_type, label, data);
+                annotation_handler_->ProcessAnnotation(block_index_, annotation_type, label, data);
             }
             else
             {
