@@ -107,7 +107,7 @@ void VulkanDecoderBase::DispatchCreateHardwareBufferCommand(
     uint32_t                                            width,
     uint32_t                                            height,
     uint32_t                                            stride,
-    uint32_t                                            usage,
+    uint64_t                                            usage,
     uint32_t                                            layers,
     const std::vector<format::HardwareBufferPlaneInfo>& plane_info)
 {
@@ -351,6 +351,91 @@ size_t VulkanDecoderBase::Decode_vkUpdateDescriptorSetWithTemplateKHR(const ApiC
     return bytes_read;
 }
 
+size_t VulkanDecoderBase::Decode_vkCreateRayTracingPipelinesKHR(const ApiCallInfo& call_info,
+                                                                const uint8_t*     parameter_buffer,
+                                                                size_t             buffer_size)
+{
+    size_t bytes_read = 0;
+
+    format::HandleId                                                device;
+    format::HandleId                                                deferredOperation;
+    format::HandleId                                                pipelineCache;
+    uint32_t                                                        createInfoCount;
+    StructPointerDecoder<Decoded_VkRayTracingPipelineCreateInfoKHR> pCreateInfos;
+    StructPointerDecoder<Decoded_VkAllocationCallbacks>             pAllocator;
+    HandlePointerDecoder<VkPipeline>                                pPipelines;
+    VkResult                                                        return_value;
+
+    bytes_read +=
+        ValueDecoder::DecodeHandleIdValue((parameter_buffer + bytes_read), (buffer_size - bytes_read), &device);
+    bytes_read += ValueDecoder::DecodeHandleIdValue(
+        (parameter_buffer + bytes_read), (buffer_size - bytes_read), &deferredOperation);
+    bytes_read +=
+        ValueDecoder::DecodeHandleIdValue((parameter_buffer + bytes_read), (buffer_size - bytes_read), &pipelineCache);
+    bytes_read +=
+        ValueDecoder::DecodeUInt32Value((parameter_buffer + bytes_read), (buffer_size - bytes_read), &createInfoCount);
+    bytes_read += pCreateInfos.Decode((parameter_buffer + bytes_read), (buffer_size - bytes_read));
+    bytes_read += pAllocator.Decode((parameter_buffer + bytes_read), (buffer_size - bytes_read));
+    bytes_read += pPipelines.Decode((parameter_buffer + bytes_read), (buffer_size - bytes_read));
+    bytes_read +=
+        ValueDecoder::DecodeEnumValue((parameter_buffer + bytes_read), (buffer_size - bytes_read), &return_value);
+
+    for (auto consumer : GetConsumers())
+    {
+        consumer->Process_vkCreateRayTracingPipelinesKHR(call_info,
+                                                         return_value,
+                                                         device,
+                                                         deferredOperation,
+                                                         pipelineCache,
+                                                         createInfoCount,
+                                                         &pCreateInfos,
+                                                         &pAllocator,
+                                                         &pPipelines);
+    }
+
+    if (deferredOperation)
+    {
+        DecodeAllocator::TurnOffEndCanClear();
+        DeferredOperationFunctionCallData record;
+        record.pCreateInfos                                        = std::move(pCreateInfos);
+        record.pAllocator                                          = std::move(pAllocator);
+        record.pPipelines                                          = std::move(pPipelines);
+        record_deferred_operation_function_call[deferredOperation] = std::move(record);
+    }
+    return bytes_read;
+}
+
+size_t VulkanDecoderBase::Decode_vkDeferredOperationJoinKHR(const ApiCallInfo& call_info,
+                                                            const uint8_t*     parameter_buffer,
+                                                            size_t             buffer_size)
+{
+    size_t bytes_read = 0;
+
+    format::HandleId device;
+    format::HandleId operation;
+    VkResult         return_value;
+
+    bytes_read +=
+        ValueDecoder::DecodeHandleIdValue((parameter_buffer + bytes_read), (buffer_size - bytes_read), &device);
+    bytes_read +=
+        ValueDecoder::DecodeHandleIdValue((parameter_buffer + bytes_read), (buffer_size - bytes_read), &operation);
+    bytes_read +=
+        ValueDecoder::DecodeEnumValue((parameter_buffer + bytes_read), (buffer_size - bytes_read), &return_value);
+
+    for (auto consumer : GetConsumers())
+    {
+        consumer->Process_vkDeferredOperationJoinKHR(call_info, return_value, device, operation);
+    }
+
+    DecodeAllocator::TurnOnEndCanClear();
+    auto it = record_deferred_operation_function_call.find(operation);
+    if (it != record_deferred_operation_function_call.end())
+    {
+        record_deferred_operation_function_call.erase(it);
+    }
+    return bytes_read;
+}
+
 void VulkanDecoderBase::DecodeFunctionCall(format::ApiCallId  call_id,
                                            const ApiCallInfo& call_info,
                                            const uint8_t*     parameter_buffer,
@@ -369,6 +454,12 @@ void VulkanDecoderBase::DecodeFunctionCall(format::ApiCallId  call_id,
         case format::ApiCallId::ApiCall_vkUpdateDescriptorSetWithTemplateKHR:
             Decode_vkUpdateDescriptorSetWithTemplateKHR(call_info, parameter_buffer, buffer_size);
             break;
+        case format::ApiCallId::ApiCall_vkCreateRayTracingPipelinesKHR:
+            Decode_vkCreateRayTracingPipelinesKHR(call_info, parameter_buffer, buffer_size);
+            break;
+        case format::ApiCallId::ApiCall_vkDeferredOperationJoinKHR:
+            Decode_vkDeferredOperationJoinKHR(call_info, parameter_buffer, buffer_size);
+            break;
         default:
             break;
     }
