@@ -598,6 +598,60 @@ enum ApiCallId : uint32_t
     ApiCall_vkGetShaderModuleCreateInfoIdentifierEXT                                              = MakeApiCallId(ApiFamily_Vulkan, 0x1278),
     ApiCall_vkGetFramebufferTilePropertiesQCOM                                                    = MakeApiCallId(ApiFamily_Vulkan, 0x1279),
     ApiCall_vkGetDynamicRenderingTilePropertiesQCOM                                               = MakeApiCallId(ApiFamily_Vulkan, 0x127a),
+    ApiCall_vkGetDeviceFaultInfoEXT                                                               = MakeApiCallId(ApiFamily_Vulkan, 0x127b),
+    ApiCall_vkCreateMicromapEXT                                                                   = MakeApiCallId(ApiFamily_Vulkan, 0x127c),
+    ApiCall_vkDestroyMicromapEXT                                                                  = MakeApiCallId(ApiFamily_Vulkan, 0x127d),
+    ApiCall_vkCmdBuildMicromapsEXT                                                                = MakeApiCallId(ApiFamily_Vulkan, 0x127e),
+    ApiCall_vkBuildMicromapsEXT                                                                   = MakeApiCallId(ApiFamily_Vulkan, 0x127f),
+    ApiCall_vkCopyMicromapEXT                                                                     = MakeApiCallId(ApiFamily_Vulkan, 0x1280),
+    ApiCall_vkCopyMicromapToMemoryEXT                                                             = MakeApiCallId(ApiFamily_Vulkan, 0x1281),
+    ApiCall_vkCopyMemoryToMicromapEXT                                                             = MakeApiCallId(ApiFamily_Vulkan, 0x1282),
+    ApiCall_vkWriteMicromapsPropertiesEXT                                                         = MakeApiCallId(ApiFamily_Vulkan, 0x1283),
+    ApiCall_vkCmdCopyMicromapEXT                                                                  = MakeApiCallId(ApiFamily_Vulkan, 0x1284),
+    ApiCall_vkCmdCopyMicromapToMemoryEXT                                                          = MakeApiCallId(ApiFamily_Vulkan, 0x1285),
+    ApiCall_vkCmdCopyMemoryToMicromapEXT                                                          = MakeApiCallId(ApiFamily_Vulkan, 0x1286),
+    ApiCall_vkCmdWriteMicromapsPropertiesEXT                                                      = MakeApiCallId(ApiFamily_Vulkan, 0x1287),
+    ApiCall_vkGetDeviceMicromapCompatibilityEXT                                                   = MakeApiCallId(ApiFamily_Vulkan, 0x1288),
+    ApiCall_vkGetMicromapBuildSizesEXT                                                            = MakeApiCallId(ApiFamily_Vulkan, 0x1289),
+    ApiCall_vkCmdSetTessellationDomainOriginEXT                                                   = MakeApiCallId(ApiFamily_Vulkan, 0x128a),
+    ApiCall_vkCmdSetDepthClampEnableEXT                                                           = MakeApiCallId(ApiFamily_Vulkan, 0x128b),
+    ApiCall_vkCmdSetPolygonModeEXT                                                                = MakeApiCallId(ApiFamily_Vulkan, 0x128c),
+    ApiCall_vkCmdSetRasterizationSamplesEXT                                                       = MakeApiCallId(ApiFamily_Vulkan, 0x128d),
+    ApiCall_vkCmdSetSampleMaskEXT                                                                 = MakeApiCallId(ApiFamily_Vulkan, 0x128e),
+    ApiCall_vkCmdSetAlphaToCoverageEnableEXT                                                      = MakeApiCallId(ApiFamily_Vulkan, 0x128f),
+    ApiCall_vkCmdSetAlphaToOneEnableEXT                                                           = MakeApiCallId(ApiFamily_Vulkan, 0x1290),
+    ApiCall_vkCmdSetLogicOpEnableEXT                                                              = MakeApiCallId(ApiFamily_Vulkan, 0x1291),
+    ApiCall_vkCmdSetColorBlendEnableEXT                                                           = MakeApiCallId(ApiFamily_Vulkan, 0x1292),
+    ApiCall_vkCmdSetColorBlendEquationEXT                                                         = MakeApiCallId(ApiFamily_Vulkan, 0x1293),
+    ApiCall_vkCmdSetColorWriteMaskEXT                                                             = MakeApiCallId(ApiFamily_Vulkan, 0x1294),
+    ApiCall_vkCmdSetRasterizationStreamEXT                                                        = MakeApiCallId(ApiFamily_Vulkan, 0x1295),
+    ApiCall_vkCmdSetConservativeRasterizationModeEXT                                              = MakeApiCallId(ApiFamily_Vulkan, 0x1296),
+    ApiCall_vkCmdSetExtraPrimitiveOverestimationSizeEXT                                           = MakeApiCallId(ApiFamily_Vulkan, 0x1297),
+    ApiCall_vkCmdSetDepthClipEnableEXT                                                            = MakeApiCallId(ApiFamily_Vulkan, 0x1298),
+    ApiCall_vkCmdSetSampleLocationsEnableEXT                                                      = MakeApiCallId(ApiFamily_Vulkan, 0x1299),
+    ApiCall_vkCmdSetColorBlendAdvancedEXT                                                         = MakeApiCallId(ApiFamily_Vulkan, 0x129a),
+    ApiCall_vkCmdSetProvokingVertexModeEXT                                                        = MakeApiCallId(ApiFamily_Vulkan, 0x129b),
+    ApiCall_vkCmdSetLineRasterizationModeEXT                                                      = MakeApiCallId(ApiFamily_Vulkan, 0x129c),
+    ApiCall_vkCmdSetLineStippleEnableEXT                                                          = MakeApiCallId(ApiFamily_Vulkan, 0x129d),
+    ApiCall_vkCmdSetDepthClipNegativeOneToOneEXT                                                  = MakeApiCallId(ApiFamily_Vulkan, 0x129e),
+    ApiCall_vkCmdSetViewportWScalingEnableNV                                                      = MakeApiCallId(ApiFamily_Vulkan, 0x129f),
+    ApiCall_vkCmdSetViewportSwizzleNV                                                             = MakeApiCallId(ApiFamily_Vulkan, 0x12a0),
+    ApiCall_vkCmdSetCoverageToColorEnableNV                                                       = MakeApiCallId(ApiFamily_Vulkan, 0x12a1),
+    ApiCall_vkCmdSetCoverageToColorLocationNV                                                     = MakeApiCallId(ApiFamily_Vulkan, 0x12a2),
+    ApiCall_vkCmdSetCoverageModulationModeNV                                                      = MakeApiCallId(ApiFamily_Vulkan, 0x12a3),
+    ApiCall_vkCmdSetCoverageModulationTableEnableNV                                               = MakeApiCallId(ApiFamily_Vulkan, 0x12a4),
+    ApiCall_vkCmdSetCoverageModulationTableNV                                                     = MakeApiCallId(ApiFamily_Vulkan, 0x12a5),
+    ApiCall_vkCmdSetShadingRateImageEnableNV                                                      = MakeApiCallId(ApiFamily_Vulkan, 0x12a6),
+    ApiCall_vkCmdSetRepresentativeFragmentTestEnableNV                                            = MakeApiCallId(ApiFamily_Vulkan, 0x12a7),
+    ApiCall_vkCmdSetCoverageReductionModeNV                                                       = MakeApiCallId(ApiFamily_Vulkan, 0x12a8),
+    ApiCall_vkGetPhysicalDeviceOpticalFlowImageFormatsNV                                          = MakeApiCallId(ApiFamily_Vulkan, 0x12a9),
+    ApiCall_vkCreateOpticalFlowSessionNV                                                          = MakeApiCallId(ApiFamily_Vulkan, 0x12aa),
+    ApiCall_vkDestroyOpticalFlowSessionNV                                                         = MakeApiCallId(ApiFamily_Vulkan, 0x12ab),
+    ApiCall_vkBindOpticalFlowSessionImageNV                                                       = MakeApiCallId(ApiFamily_Vulkan, 0x12ac),
+    ApiCall_vkCmdOpticalFlowExecuteNV                                                             = MakeApiCallId(ApiFamily_Vulkan, 0x12ad),
+    ApiCall_vkCmdDrawMeshTasksEXT                                                                 = MakeApiCallId(ApiFamily_Vulkan, 0x12ae),
+    ApiCall_vkCmdDrawMeshTasksIndirectEXT                                                         = MakeApiCallId(ApiFamily_Vulkan, 0x12af),
+    ApiCall_vkCmdDrawMeshTasksIndirectCountEXT                                                    = MakeApiCallId(ApiFamily_Vulkan, 0x12b0),
 
     ApiCall_VulkanLast
     // clang-format on
