@@ -1,6 +1,6 @@
 /*
-** Copyright (c) 2018-2020 Valve Corporation
-** Copyright (c) 2018-2020 LunarG, Inc.
+** Copyright (c) 2018-2022 Valve Corporation
+** Copyright (c) 2018-2022 LunarG, Inc.
 **
 ** Permission is hereby granted, free of charge, to any person obtaining a
 ** copy of this software and associated documentation files (the "Software"),
@@ -20,6 +20,7 @@
 ** FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 ** DEALINGS IN THE SOFTWARE.
 */
+/// @file Definition of the capture file format.
 
 #ifndef GFXRECON_FORMAT_FORMAT_H
 #define GFXRECON_FORMAT_FORMAT_H
@@ -58,6 +59,10 @@ const size_t   kUuidSize                  = 16;
 const size_t   kMaxPhysicalDeviceNameSize = 256;
 const HandleId kNullHandleId              = 0;
 
+/// Label for operation annotation, which captures parameters used by tools
+/// operating on a capture file.
+const char* const kAnnotationLabelOperation = "operation";
+
 constexpr uint32_t MakeCompressedBlockType(uint32_t block_type)
 {
     return kCompressedBlockTypeBit | block_type;
@@ -104,7 +109,7 @@ enum class MetaDataType : uint16_t
     kEndResourceInitCommand                 = 6,
     kInitBufferCommand                      = 7,
     kInitImageCommand                       = 8,
-    kCreateHardwareBufferCommand            = 9,
+    kCreateHardwareBufferCommand_deprecated = 9,
     kDestroyHardwareBufferCommand           = 10,
     kSetDevicePropertiesCommand             = 11,
     kSetDeviceMemoryPropertiesCommand       = 12,
@@ -119,6 +124,9 @@ enum class MetaDataType : uint16_t
     kReserved21                             = 21,
     kReserved22                             = 22,
     kReserved23                             = 23,
+    kCreateHardwareBufferCommand            = 24,
+    kReserved25                             = 25,
+    kReserved26                             = 26,
 };
 
 // MetaDataId is stored in the capture file and its type must be uint32_t to avoid breaking capture file compatibility.
@@ -259,7 +267,7 @@ struct AnnotationHeader
     BlockHeader    block_header;
     AnnotationType annotation_type;
     uint32_t       label_length;
-    uint32_t       data_length;
+    uint64_t       data_length;
 };
 
 // Metadata block headers and data types.
@@ -312,7 +320,9 @@ struct ResizeWindowCommand2
     uint32_t         pre_transform;
 };
 
-struct CreateHardwareBufferCommandHeader
+// This command header's "usage" member is sized incorrectly.  Existing decoding must remain in place in order to
+// process captures that already exist.  Do not use this command header in any new code.
+struct CreateHardwareBufferCommandHeader_deprecated
 {
     MetaDataHeader meta_header;
     ThreadId       thread_id;
@@ -328,6 +338,22 @@ struct CreateHardwareBufferCommandHeader
                            // HardwareBufferLayerInfo records.  When unavailable, 'planes' is zero.
 };
 
+struct CreateHardwareBufferCommandHeader
+{
+    MetaDataHeader meta_header;
+    ThreadId       thread_id;
+    HandleId       memory_id; // Globally unique ID assigned to the buffer for tracking memory modifications.
+    uint64_t       buffer_id; // Address of the buffer object.
+    uint32_t       format;
+    uint32_t       width;
+    uint32_t       height;
+    uint32_t       stride; // Size of a row in pixels.
+    uint64_t       usage;
+    uint32_t       layers;
+    uint32_t       planes; // When additional multi-plane data is available, header is followed by 'planes' count
+                           // HardwareBufferLayerInfo records.  When unavailable, 'planes' is zero.
+};
+
 struct HardwareBufferPlaneInfo
 {
     uint64_t offset;       // Offset from the start of the memory allocation in bytes.
