@@ -1,5 +1,6 @@
 /*
-** Copyright (c) 2021 LunarG, Inc.
+** Copyright (c) 2021-2022 LunarG, Inc.
+** Copyright (c) 2022 Valve Corporation
 **
 ** Permission is hereby granted, free of charge, to any person obtaining a
 ** copy of this software and associated documentation files (the "Software"),
@@ -19,6 +20,8 @@
 ** FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 ** DEALINGS IN THE SOFTWARE.
 */
+/// @file Facilities for the conversion of types to strings, oriented  towards
+/// JSON Lines output.
 
 #ifndef GFXRECON_TO_STRING_H
 #define GFXRECON_TO_STRING_H
@@ -36,11 +39,13 @@ enum ToStringFlagBits
 {
     kToString_Unformatted = 0,
     kToString_Formatted   = 1,
-    kToString_Default     = kToString_Formatted,
+    kToString_Default     = kToString_Unformatted,
 };
 
 typedef uint32_t ToStringFlags;
 
+/// @brief  A template ToString to take care of simple POD cases like the many
+/// types of integers and the 32 bit and 64 bit floating point types.
 template <typename T>
 inline std::string
 ToString(const T& obj, ToStringFlags toStringFlags = kToString_Default, uint32_t tabCount = 0, uint32_t tabSize = 4)
@@ -51,6 +56,14 @@ ToString(const T& obj, ToStringFlags toStringFlags = kToString_Default, uint32_t
     return std::to_string(obj);
 }
 
+/// @brief A template that exists only to allow the ToStrings for 32 bit sets of
+/// flags to be template specializations.
+/// It is never called and its return value of "0" is a meaningless placeholder
+/// to allow compilation to succeed.
+/// @note There seems to be no reason for those ToStrings to be template
+/// function specializations since a caller has to explicitly spell out a type
+/// to call one of them and there is no function resolution based on argument
+/// types going on.
 template <typename T>
 inline std::string ToString(uint32_t      apiFlags,
                             ToStringFlags toStringFlags = kToString_Default,
@@ -61,9 +74,15 @@ inline std::string ToString(uint32_t      apiFlags,
     GFXRECON_UNREFERENCED_PARAMETER(toStringFlags);
     GFXRECON_UNREFERENCED_PARAMETER(tabCount);
     GFXRECON_UNREFERENCED_PARAMETER(tabSize);
+
     return "0";
 }
 
+inline std::string Bool32ToString(const /* Don't take the header dependency for one typedef: VkBool32*/ uint32_t b)
+{
+    return b ? "true" : "false";
+}
+
 template <typename PtrType>
 inline std::string PtrToString(PtrType* ptr)
 {
@@ -100,12 +119,13 @@ inline std::string
 ObjectToString(ToStringFlags toStringFlags, uint32_t& tabCount, uint32_t tabSize, ToStringFunctionType toStringFunction)
 {
     std::stringstream strStrm;
+    const auto        nl = GetNewlineString(toStringFlags);
     strStrm << '{';
-    strStrm << GetNewlineString(toStringFlags);
+    strStrm << nl;
     ++tabCount;
     toStringFunction(strStrm);
     --tabCount;
-    strStrm << GetNewlineString(toStringFlags);
+    strStrm << nl;
     strStrm << GetTabString(toStringFlags, tabCount, tabSize);
     strStrm << '}';
     return strStrm.str();
@@ -113,7 +133,7 @@ ObjectToString(ToStringFlags toStringFlags, uint32_t& tabCount, uint32_t tabSize
 
 inline void FieldToString(std::stringstream& strStrm,
                           bool               firstField,
-                          const std::string& fieldName,
+                          const char*        fieldName,
                           ToStringFlags      toStringFlags,
                           uint32_t           tabCount,
                           uint32_t           tabSize,
@@ -130,7 +150,7 @@ inline void FieldToString(std::stringstream& strStrm,
 }
 
 template <typename ObjectType, typename ValidateArrayFunctionType, typename ToStringFunctionType>
-inline std::string ArrayToString(uint32_t                  count,
+inline std::string ArrayToString(size_t                    count,
                                  const ObjectType*         pObjs,
                                  ToStringFlags             toStringFlags,
                                  uint32_t                  tabCount,
@@ -138,27 +158,29 @@ inline std::string ArrayToString(uint32_t                  count,
                                  ValidateArrayFunctionType validateArrayFunction,
                                  ToStringFunctionType      toStringFunction)
 {
+    if (!(count && validateArrayFunction()))
+    {
+        return "null";
+    }
+
     std::stringstream strStrm;
     strStrm << '[';
-    if (count && validateArrayFunction())
+    strStrm << GetNewlineString(toStringFlags);
+    for (uint32_t i = 0; i < count; ++i)
     {
-        strStrm << GetNewlineString(toStringFlags);
-        for (uint32_t i = 0; i < count; ++i)
+        if (i)
         {
-            if (i)
-            {
-                strStrm << ',' << GetNewlineString(toStringFlags);
-            }
-            strStrm << GetTabString(toStringFlags, tabCount + 1, tabSize) << toStringFunction(i);
+            strStrm << ',' << GetNewlineString(toStringFlags);
         }
-        strStrm << GetNewlineString(toStringFlags) << GetTabString(toStringFlags, tabCount, tabSize);
+        strStrm << GetTabString(toStringFlags, tabCount + 1, tabSize) << toStringFunction(i);
     }
+    strStrm << GetNewlineString(toStringFlags) << GetTabString(toStringFlags, tabCount, tabSize);
     strStrm << ']';
     return strStrm.str();
 }
 
 template <typename T>
-inline std::string ArrayToString(uint32_t      count,
+inline std::string ArrayToString(size_t        count,
                                  const T*      pObjs,
                                  ToStringFlags toStringFlags = kToString_Default,
                                  uint32_t      tabCount      = 0,
@@ -174,7 +196,104 @@ inline std::string ArrayToString(uint32_t      count,
         [&](uint32_t i) { return ToString(pObjs[i], toStringFlags, tabCount + 1, tabSize); });
 }
 
-inline std::string CStrArrayToString(uint32_t           count,
+template <typename T>
+inline std::string Array2DToString(size_t          m,
+                                   size_t          n,
+                                   const T* const* pObjs,
+                                   ToStringFlags   toStringFlags = kToString_Default,
+                                   uint32_t        tabCount      = 0,
+                                   uint32_t        tabSize       = 4)
+{
+    std::stringstream strStrm;
+    for (size_t i = 0; i < m; ++i)
+    {
+        strStrm << ArrayToString(n, pObjs[i], toStringFlags, tabCount, tabSize);
+    }
+    return strStrm.str();
+}
+
+/// Replace special characters with their escaped versions.
+/// @note forward slash / solidus is not escaped as that is optional and leads
+/// to ugliness such as dates with escaped solidus separators.
+/// @note Slashes for explicit unicode code points will be erroneously escaped
+/// but Vulkan-derived C-strings should not have those embedded.
+inline void JSONEscape(const char c, std::string& out)
+{
+    char out_c = c;
+    switch (c)
+    {
+        case '\"':
+        case '\\':
+            out.push_back('\\');
+            break;
+        case '\b':
+            out.push_back('\\');
+            out_c = 'b';
+            break;
+        case '\f':
+            out.push_back('\\');
+            out_c = 'f';
+            break;
+        case '\n':
+            out.push_back('\\');
+            out_c = 'n';
+            break;
+        case '\r':
+            out.push_back('\\');
+            out_c = 'r';
+            break;
+        case '\t':
+            out.push_back('\\');
+            out_c = 't';
+            break;
+    }
+    out.push_back(out_c);
+}
+
+/// Replace special characters in strings with their escaped versions.
+/// <https://www.json.org/json-en.html>
+inline void JSONEscape(const char* cstr, std::string& escaped)
+{
+    if (cstr)
+    {
+        while (char c = *cstr++)
+        {
+            JSONEscape(c, escaped);
+        }
+    }
+}
+
+inline std::string JSONEscape(const std::string& str)
+{
+    std::string escaped;
+    for (const auto c : str)
+    {
+        JSONEscape(c, escaped);
+    }
+    return escaped;
+}
+
+/// @brief  A single point for the conversion of C-style strings to the JSON
+/// string type or null.
+inline std::string CStrToString(const char* const cstr)
+{
+    std::string str;
+    if (cstr != nullptr)
+    {
+        str.push_back('"');
+        JSONEscape(cstr, str);
+        str.push_back('"');
+    }
+    else
+    {
+        str.assign("null");
+    }
+    return str;
+}
+
+/// @brief  Convert an array of c-style string pointers into a JSON array of
+/// JSON strings or nulls.
+inline std::string CStrArrayToString(size_t             count,
                                      const char* const* ppStrs,
                                      ToStringFlags      toStringFlags = kToString_Default,
                                      uint32_t           tabCount      = 0,
@@ -187,7 +306,28 @@ inline std::string CStrArrayToString(uint32_t           count,
         tabCount,
         tabSize,
         [&]() { return ppStrs != nullptr; },
-        [&](uint32_t i) { return ppStrs[i] ? ('"' + std::string(ppStrs[i]) + '"') : "null"; });
+        [&](uint32_t i) { return CStrToString(ppStrs[i]); });
+}
+
+/// @brief Make a copy of the input string with double quotes at start and end.
+inline std::string Quote(const std::string& str)
+{
+    std::string quoted{ '"' };
+    quoted += str;
+    quoted += '"';
+    return quoted;
+}
+
+/// @brief Make a copy of the input string with double quotes at start and end.
+inline std::string Quote(const char* const str)
+{
+    std::string quoted{ '"' };
+    if (str != nullptr)
+    {
+        quoted += str;
+    }
+    quoted += '"';
+    return quoted;
 }
 
 GFXRECON_END_NAMESPACE(util)
